@@ -59,6 +59,10 @@
 #define ALT_TOG_STR	"\005"
 #define ITALIC_TOG	'\020'		/* ^P */
 #define ITALIC_TOG_STR	"\020"
+#define COLOR_TAG	'\003'		/* ^C */
+#define COLOR_TAG_STR	"\003"
+#define COLOR256_TAG	'\030'		/* ^X */
+#define	COLOR256_TAG_STR "\030"
 
 #define IRCD_BUFFER_SIZE	512
 /* Last two bytes are always reserved for \r\n */
@@ -85,6 +89,7 @@ extern		int	background;
 extern		int	current_numeric;
 extern		int	dead;
 extern volatile	int	dead_children_processes;
+extern		int	dont_connect;
 extern		int	dumb_mode;
 extern		int	foreground;
 extern		int	global_beep_ok;
@@ -139,6 +144,7 @@ extern struct timeval	idle_time;
 extern struct timeval	now;
 extern struct timeval	input_timeout;
 extern	unsigned	window_display;		/* This is in window.h */
+extern		jmp_buf	panic_jumpseat;
 
 /* irc.c's extern functions */
 	void	io 			(const char *);
